Files
TheRock/rocm-systems/projects/rocr-runtime/rocrtst/Kernels/write_kernel.cl
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

46 lines
1.3 KiB
Common Lisp

/*
* Copyright © Advanced Micro Devices, Inc., or its affiliates.
*
* SPDX-License-Identifier: MIT
*/
/**
* @brief Opencl kernel to write into a buffer the values of const integer list
*
* @param dst Pointer to an array of 16 unsigned integers (32-bit) i.e. one instance
* has 16 * 32-bit = 64 bytes
*
* @param size Specifies number of uint16 elements in the array
*
* @param threads Number of threads running this kernel
*
* @note: It is critical that the size of 'dst' be a integral multiple
* of (threads * sizeof(uint16)). If it is fractional and less than ONE
* it will lead to accessing memory that is out-of-bounds. If it is fractional
* more but more than ONE then it will lead to some threads not doing work
* at all leading to incorrect benchmark computation
*
*/
__kernel void
write_kernel(__global uint16 *dst,
ulong size, uint threads) {
uint16 pval = (uint16)(0xabababab, 0xabababab, 0xabababab, 0xabababab,
0xabababab, 0xabababab, 0xabababab, 0xabababab,
0xabababab, 0xabababab, 0xabababab, 0xabababab,
0xabababab, 0xabababab, 0xabababab, 0xabababab);
int idx = get_global_id(0);
__global uint16 *dstEnd = dst + size;
dst = &dst[idx];
do {
*dst = pval;
dst += threads;
} while (dst < dstEnd);
}